import sys
import typing

GenericType = typing.TypeVar("GenericType")


def poly_3d_calc(veclist: typing.Any, pt: typing.Any):
    ''' Calculate barycentric weights for a point on a polygon.

    :param veclist:  list of vectors
    :type veclist: typing.Any
    :param pt:  list of per-vector weights
    :type pt: typing.Any
    '''

    pass
